@@ -17,24 +17,24 @@ use Storable 3.15 'dclone';
 
 no warnings 'experimental';
 
-our $VERSION='0.021';
+our $VERSION='0.022';
 
 =head1 NAME
 
 Vote::Count
 
 
-=head1 VERSION 0.021
+=head1 VERSION 0.022
 
 =cut
 
 # ABSTRACT: Parent Module for Vote::Count. Toolkit for vote counting.
 
-has 'BallotSet' => ( is => 'ro', isa => 'HashRef' );
+has 'BallotSet' => ( is => 'ro', isa => 'HashRef', required => 1 );
+
 has 'BallotSetType' => (
   is      => 'ro',
   isa     => 'Str',
-  lazy    => 1,
   default =>  'rcv',
 );
 
@@ -42,24 +42,30 @@ has 'Active' => (
   is => 'rw',
   isa => 'HashRef',
   lazy => 1,
-  builder => '_buildactive', );
+  builder => 'ResetActive', );
 
-sub _buildactive ( $self ) { return dclone $self->BallotSet()->{'choices'} }
+sub ResetActive ( $self ) { return dclone $self->BallotSet()->{'choices'} }
 
 sub SetActive ( $self, $active ) {
   # Force deref
-  $self->{'Active'} = { $active->%* };
+  $self->{'Active'} = dclone $active;
+}
+
+# I was typing the equivalent too often. made a method.
+sub SetActiveFromArrayRef ( $self, $active ) {
+  $self->{'Active'} = { map { $_ => 1 } $active->@* };
 }
 
 sub GetActive ( $self ) {
   # Force deref
-  return { $self->Active()->%* }
+  my $active = $self->Active();
+  return dclone $active;
 }
 
-has 'LogTo' => (
-  is => 'rw',
+has TieBreakMethod => (
+  is  => 'rw',
   isa => 'Str',
-  default => '/tmp/votecount',
+  required => 0,
 );
 
 has 'PairMatrix' => (
@@ -69,10 +75,14 @@ has 'PairMatrix' => (
   builder => '_buildmatrix', );
 
 sub _buildmatrix ( $self ) {
-
+  my $tiebreak = defined($self->TieBreakMethod())
+    ? $self->TieBreakMethod()
+    : 'none';
   return  Vote::Count::Matrix->new(
     BallotSet => $self->BallotSet(),
-    Active => $self->Active()
+    Active => $self->Active(),
+    TieBreakMethod => $tiebreak,
+    LogTo => $self->LogTo() . '_matrix',
   )
 }
 
@@ -95,58 +105,18 @@ sub BUILD {
   $self->{'LogT'} = '';
 }
 
-sub logt {
-  my $self = shift @_;
-  return $self->{'LogT'} unless ( @_) ;
-  my $msg = join( "\n", @_ ) . "\n";
-  $self->{'LogT'} .= $msg;
-  $self->{'LogV'} .= $msg;
-  $self->logd( @_);
-}
-
-sub logv {
-  my $self = shift @_;
-  return $self->{'LogV'} unless ( @_) ;
-  my $msg = join( "\n", @_ ) . "\n";
-  $self->{'LogV'} .= $msg;
-  $self->logd( @_);
-}
-
-sub logd {
-  my $self = shift @_;
-  return $self->{'LogD'} unless ( @_) ;
-  my @args = (@_);
-  # since ops are seqential and fast logging event times
-  # clutters the debug log.
-  # unshift @args, localtime->date . ' ' . localtime->time;
-  my $msg = join( "\n", @args ) . "\n";
-  $self->{'LogD'} .= $msg;
-}
-
-sub WriteLog {
-  my $self = shift @_;
-  my $logroot = $self->LogTo();
-  path( "$logroot.brief")->spew( $self->logt() );
-  path( "$logroot.full")->spew( $self->logv() );
-  path( "$logroot.debug")->spew( $self->logd() );
-}
-
 # load the roles providing the underlying ops.
 with  'Vote::Count::Approval',
       'Vote::Count::Borda',
       'Vote::Count::Floor',
       'Vote::Count::IRV',
+      'Vote::Count::Log',      
       'Vote::Count::TieBreaker',
       'Vote::Count::TopCount',
       ;
 
 sub VotesCast ( $self ) {
   return $self->BallotSet()->{'votescast'};
-  # my $numvotes = 0;
-  # for my $ballot ( keys $ballots->%* ) {
-  #   $numvotes += $ballots->{$ballot}{'count'};
-  # }
-  # return $numvotes;
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -222,7 +192,7 @@ This is also extremely useful to researchers who may want to study multiple meth
 
 =head1 Preview Release
 
-This module is not ready for production.
+This module is not ready for production. 
 
 
 =head1 Overview
@@ -260,7 +230,7 @@ The Consistency Criteria collectively state: Changes to non-winning alternatives
 
 To illustrate inconsistency: suppose every morning we vote on a flavor of Ice Cream and Chocolate always wins; one morning the three voters who always vote 1:RockyRoad 2:Chocolate simply vote for Chocolate, consistency is violated if Chocolate loses on that day.
 
-Cloning occurs when similar choices are available, such as Vanilla and Vanilla Bean. If removing one of the clones would cause the other to win, the presence of both should not cause a non-clone to win.
+Cloning occurs when similar choices are available, such as Vanilla and Vanilla Bean. If one of the clones would win without the presence of the other, the presence of both should not cause a non-clone to win.
 
 The cases described above: Monotonocity, Independence of Irrelevant Alternatives and Clone Independence are normally discussed as seperate criteria rather than components of one. Additional sub-criteria that haven't been mentioned include: Reversal Symmetry, Participation Consistency, and Later No Help (which could also be considered a sub-criteria of Later Harm).
 
@@ -272,7 +242,7 @@ Is it feasible to count 100 ballots by hand? How difficult is it to understand t
 
 =head4 Resolvability
 
-I<Majority> meets all of the above criteria, however, unless votes are restricted to two choices, it will frequently fail to provide a winner, or even a tie. No method can be completely impervious to ties. Methods that are not Resolvable are frequently combined with other methods, I<Instant Runoff Voting> is a compound method with I<Majority>, and all usable I<Condorcet> Methods combine seeking a Condorcet Winner with some other process for when there isn't one.
+I<Majority> meets all of the above criteria, however, unless votes are restricted to two choices, it will frequently fail to provide a winner, or even a tie. No method can be completely impervious to ties. Methods that are not Resolvable are frequently combined with other methods, I<Instant Runoff Voting> is a compound method with I<Majority>, and all usable I<Condorcet> Methods combine seeking a Condorcet Winner with some other process.
 
 
 =head4 Incentive for Strategic Voting
@@ -345,7 +315,7 @@ Inconsistant.
 
 =item *
 
-Vulnerable to a Cloning Attack.
+The basic Borda Method is vulnerable to a Cloning Attack.
 
 
 =back
@@ -355,7 +325,7 @@ Vulnerable to a Cloning Attack.
 
 Technically this family of methods should be called Condorcet Pairwise, because any method that meets both Condorcet Criteria is technically a Condorcet Method. However, in discussion and throughout this software collection the term Condorcet will refer to  methods which uses a Matrix of Wins and Losses derived from direct pairing of choices and seeks to identify a Condorcet Winner.
 
-The basic Condorcet Method will frequently fail to identify a winner. One possibility is a Loop (Condorcet's Paradox) Where A > B, B > C, and C > A. Another possibility is a knot (not an accepted term, but one which will be used in this documentation). A Loop can be considered a tie, and a Knot can be considered something less than a tie. To make Condorcet resolvable a second method is typically used to resolve Loops and Knots.
+The basic Condorcet Method will frequently fail to identify a winner. One possibility is a Loop (Condorcet's Paradox) Where A > B, B > C, and C > A. Another possibility is a knot (not an accepted term, but one which will be used in this documentation). To make Condorcet resolvable a second method is typically used to resolve Loops and Knots.
 
 =over
 
@@ -382,16 +352,18 @@ When a Condorcet Winner is present Consistency is met. When there is no Condorce
 =back
 
 
-=head3 Score Voting Systems
+=head3 Score (Range) Voting Systems
 
-Most Methods for Ranked Choice Ballots can be used for Score Ballots, either directly or by translating the ballots. Score Voting proposals typically implement I<Borda Count>,with a fixed depth of choices. I<STAR>, creates a virtual runoff between the top two I<Borda Count> Choices.
+Most Methods for Ranked Choice Ballots can be used for Score Ballots, either directly or by translating the ballots. Score Voting proposals typically implement I<Borda Count>, with a fixed depth of choices. I<STAR>, creates a virtual runoff between the top two I<Borda Count> Choices.
 
-Advocates of Score Voting claim that this Ballot Style it is a better expression of voter preference (which is purely a matter of opinion and cannot be proved or disproved), but it does create more potential for ties in the resolution process than RC does (which is a reason to assert RC is better).
+Advocates of Score Voting claim that this Ballot Style is a better expression of voter preference (which is purely a matter of opinion and cannot be proved or disproved), but it does create more potential for ties in the resolution process than RC does (which is a reason to assert RC is better). 
+
+Borda appears to benefit from a switch to Score Ballots, while IRV and Condorcet are better served by Ranked Ballots.
 
 
 =head1 Objective and Motivation
 
-I wanted to be able to evaluate alternative methods for resolving elections and couldn't find a flexible enough existing libary in any of the popular general purpose and web development languages: Perl, PHP, Python, Ruby, JavaScript, nor in the newer language Julia (created as an alternative to R and other math languages). More recently I was writing a bylaws proposal to use RCV and found that the existing libraries and services were not only constrained in what options they can provide, but also didn't document them clearly, making it a challenge to have a method described in bylaws where it could be guaranteed hand and machine counts would agree.
+I wanted to be able to evaluate alternative methods for resolving elections and couldn't find a flexible enough existing libary in any of the popular general purpose and web development languages: Perl, PHP, Python, Ruby, JavaScript, nor in the newer language Julia (created as an alternative to R and other math languages). More recently I was writing a bylaws proposal to use RCV and found that the existing libraries and services were not only constrained in what options they can provide, but also didn't always document them clearly, making it a challenge to have a method described in bylaws where it could be guaranteed hand and machine counts would agree.
 
 The objective is to have a library that can handle any of the myriad variants that one might consider either from a study perspective or what is called for by the elections rules of our entity.
 
@@ -406,7 +378,7 @@ The Vote::Count::ReadBallots library provides functionality for reading files fr
 
 =head2 Voting Method and Component Modules
 
-The Modules in the space Vote::Count::%Component% provide functionality needed to create a functioning Voting Method. Many of these are consumed as Roles by the Vote::Count object, some such as RankCount and Matrix are not roles and return their own objects.
+The Modules in the space Vote::Count::%Component% provide functionality needed to create a functioning Voting Method. Many of these are consumed as Roles by the Vote::Count object, some such as RankCount and Matrix return their own objects.
 
 The Modules in the space Vote::Count::Method::%Something% implement a Voting Method such as IRV. These Modules inherit the parent Vote::Count and all of the Components available to it. These modules all return a Hash Reference with the following key: I<winner>, some return additional keys. Methods that can be tied will have additional keys I<tie> and I<tied>. When there is no winner the value of I<winner> will be false.
 
@@ -557,7 +529,7 @@ L<Vote::Count::RankCount|https://metacpan.org/pod/Vote::Count::RankCount>
 =back
 
 
-=head2 Voting Methods
+=head3 Voting Methods
 
 =over
 
@@ -574,7 +546,7 @@ L<Vote::Count::Method::IRV|https://metacpan.org/pod/Vote::Count::Method::IRV>
 =back
 
 
-=head2 Non Object Oriented Components
+=head3 Non Object Oriented Components
 
 =over
 
@@ -586,7 +558,7 @@ L<Vote::Count::Redact|https://metacpan.org/pod/Vote::Count::Redact>
 =back
 
 
-=head2 Utilities
+=head3 Utilities
 
 =over
 
@@ -595,6 +567,32 @@ L<Vote::Count::Redact|https://metacpan.org/pod/Vote::Count::Redact>
 L<Vote::Count::ReadBallots|https://metacpan.org/pod/Vote::Count::ReadBallots>
 
 
+=item *
+
+L<Vote::Count::Start|https://metacpan.org/pod/Vote::Count::Start>
+
+
+
+=back
+
+
+=head3 Documentation
+
+Additional Documentation Files
+
+=over
+
+=item *
+
+L<Vote::Count::HandCount|https://metacpan.org/pod/distribution/Vote-Count/lib/Vote/Count/Method/HandCount.pod>
+
+
+=item *
+
+L<Vote::Count::Start|https://metacpan.org/pod/Vote::Count::Start>
+
+
+
 =back
 
 
